<?php

namespace Drupal\Tests\raven\Functional;

use Drupal\Component\Serialization\Json;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests Raven module.
 *
 * @group raven
 */
class RavenTest extends BrowserTestBase {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Modules to install.
   *
   * @var string[]
   */
  protected static $modules = ['raven', 'raven_test'];

  /**
   * Tests Raven module configuration UI and hooks.
   */
  public function testRavenConfigAndHooks(): void {
    $admin_user = $this->drupalCreateUser(['administer site configuration']);
    $this->drupalLogin($admin_user);
    $this->drupalGet('admin/config/development/logging');
    $config['raven[php][client_key]'] = 'https://user:password@sentry.test/123456';
    $config['raven[php][fatal_error_handler]'] = 1;
    foreach (range(1, 8) as $level) {
      $config["raven[php][log_levels][$level]"] = '1';
    }
    $this->submitForm($config, $this->t('Save configuration'));
    $this->assertSession()->responseHeaderEquals('X-Logged', 'Logged');
    $this->assertNull($this->getSession()->getResponseHeader('X-Not-Logged'));
    $path = $this->container->get('extension.list.module')->getPath('raven_test');
    $this->assertSession()->responseHeaderEquals('X-Stacktrace-File', "$path/raven_test.module");
    $cookies = Json::decode($this->getSession()->getResponseHeader('X-Logged-Cookies'));
    $this->assertSame('********', end($cookies));

    // Test fatal error handling.
    $memory_limit = mt_rand(16000000, 17999999);
    $url = $admin_user->toUrl()->setOption('query', ['memory_limit' => $memory_limit]);
    // Output should be the memory limit and 0 pending events/requests.
    $this->assertEquals($memory_limit . '00', $this->drupalGet($url));

    // Test ignored channels.
    $this->drupalGet('admin/config/development/logging');
    $config = ['raven[php][ignored_channels]' => "X-Logged\r\n"];
    $this->submitForm($config, $this->t('Save configuration'));
    $this->assertNull($this->getSession()->getResponseHeader('X-Logged'));

    // Test that logger can be serialized.
    serialize($this->container->get('logger.raven'));
  }

}
